@@ -1,5 +1,5 @@
 package Encode::JIS2K;
-our $VERSION = sprintf "%d.%02d", q$Revision: 0.04 $ =~ /(\d+)/g;
+our $VERSION = sprintf "%d.%02d", q$Revision: 0.05 $ =~ /(\d+)/g;
 
 use Encode;
 use XSLoader;
@@ -36,8 +36,8 @@ JIS 2000, hence the module name).  Encodings supported are as follows.
 
   Canonical     Alias                                      Description
   --------------------------------------------------------------------
-  euc-jisx0213  qr/\beuc.*jp[ \-]?(?:2000|2k)$/i          EUC-JISX0213 
-                qr/\bjp.*euc[ \-]?(2000|2k)$/i 
+  euc-jisx0213  qr/\beuc.*jp[ \-]?(?:2000|2k)$/i          EUC-JISX0213
+                qr/\bjp.*euc[ \-]?(2000|2k)$/i
                 qr/\bujis[ \-]?(?:2000|2k)$/i
   shiftjisx0213 qr/\bshift.*jis(?:2000|2k)$/i           Shift_JISX0213
                 qr/\bsjisp \-]?(?:2000|2k)$/i
@@ -64,7 +64,7 @@ And here is the character repertoire there of at a glance.
 
           # of codepoints     Kuten Ku (rows) used
   --------------------------------------------------------
-  JIS X 0208         6,879    1..8,16..83 
+  JIS X 0208         6,879    1..8,16..83
   JIS X 0213-1       8,762    1..94 (all!)
   JIS X 0212         6,067    2,6..7,9..11,16..77
   JIS X 0213-2       2,436    1,3..5,8,12..15,78..94
@@ -82,11 +82,11 @@ characteristics are as a result thereof.
 JIS X plane 1 is (almost) a superset of JIS X 0208.  However, with
 Unicode 3.2.0 the mappings differ in 3 codepoints.
 
-  Kuten   JIS X 0208 -> Unicode         JIS X 0213 -> Unicode 
+  Kuten   JIS X 0208 -> Unicode         JIS X 0213 -> Unicode
   --------------------------------------------------------------
   1-1-17  <UFFE3> # FULLWIDTH MACRON    <U203E> # OVERLINE
   1-1-29  <U2014> # EM DASH             <U2015> # HORIZONTAL BAR
-  1-1-79  <UFFE5> # FULLWIDTH YEN SIGN  <U00A5> # YEN SIGN          
+  1-1-79  <UFFE5> # FULLWIDTH YEN SIGN  <U00A5> # YEN SIGN
 
 =item *
 
@@ -95,7 +95,7 @@ By the same token, JIS X 0213 plane 2 contains JIS Dai-4 Suijun Kanji
 both JIS X 0212 and JIS 0213 plane 2.
 
 However, JIS X 0212:1990 already contains many of Dai-4 Suijun Kanji
-so EUC's G3 is subject to containing duplicate mappings. 
+so EUC's G3 is subject to containing duplicate mappings.
 
 =item *
 
@@ -103,7 +103,7 @@ Because of Halfwidth Katakana, Shift_JIS mapping has been tricky and
 it is even trickier.  Here is a regex that matches Shift_JISX0213
 sequence (note: you have to "use bytes" to make it work!)
 
-  $re_valid_shifjisx0213 = 
+  $re_valid_shifjisx0213 =
     qr/^(?:
          [\x00-\x7f] |                            # ASCII or
 	 [\xa1-\xdf] |                            # JIS X 0201 KANA or
@@ -121,19 +121,19 @@ However, 'euc-jp' in Encode and 'euc-jisx0213' differ as follows;
   --------------------------------------------------------------
   Decodes....       (0201-K|0208|0212|0213)  ditto
   Round-Trip  (|0)  (020-K|0208|0212)        JIS X (0201-K|0213)
-  Decode Only (|3)  those only found in 0213   
+  Decode Only (|3)  those only found in 0213
                                         those only found in 0212
   --------------------------------------------------------------
 
 =head1 AUTHORS
 
-Dan Kogai E<lt>dankogai@dan.co.jpE<gt>
+Dan Kogai, C<< <dankogai+cpan at gmail.com> >>
 
 =head1 COPYRIGHT
 
-Copyright 2002 by Dan Kogai E<lt>dankogai@dan.co.jpE<gt>.
+Copyright 2002-2023 by Dan Kogai C<< <dankogai+cpan at gmail.com> >>.
 
-This program is free software; you can redistribute it and/or 
+This program is free software; you can redistribute it and/or
 modify it under the same terms as Perl itself.
 
 See L<http://www.perl.com/perl/misc/Artistic.html>
@@ -142,7 +142,7 @@ See L<http://www.perl.com/perl/misc/Artistic.html>
 
 L<Encode>, L<Encode::JP>
 
-Japanese Graphic Character Set for Information Interchange -- Plane 1 
+Japanese Graphic Character Set for Information Interchange -- Plane 1
 L<http://www.itscj.ipsj.or.jp/ISO-IR/228.pdf>
 
 Japanese Graphic Character Set for Information Interchange -- Plane 2
